/*
 * Created on 02.08.2005 for PIROL
 *
 * SVN header information:
 *  $Author: LBST-PF-3\orahn $
 *  $Rev: 2509 $
 *  $Date: 2006-10-06 12:01:50 +0200 (Fr, 06 Okt 2006) $
 *  $Id: PirolPlugInMessages.java 2509 2006-10-06 10:01:50Z LBST-PF-3\orahn $
 */
package de.fhOsnabrueck.jump.pirol.utilities.i18n;

import java.util.MissingResourceException;

import de.fhOsnabrueck.jump.pirol.utilities.apiTools.HandlerToMakeYourLifeEasier;
import de.fhOsnabrueck.jump.pirol.utilities.debugOutput.DebugUserIds;
import de.fhOsnabrueck.jump.pirol.utilities.debugOutput.PersonalLogger;


/**
 * Handles i18n stuff for PIROL plugIns.<br>
 * Class that Eclipse generates, if the "Externalize Strings" command is used. Was renamed (from <code>Messages.java</code>) and modified to use the openJump i18n plug - the interface stayed the same!<br>
 * Wrapper for the i18N to make work with PIROL labels easier.
 *
 * @author Ole Rahn
 * <br>
 * <br>FH Osnabr&uuml;ck - University of Applied Sciences Osnabr&uuml;ck,
 * <br>Project: PIROL (2005),
 * <br>Subproject: Daten- und Wissensmanagement
 * 
 * @version $Rev: 2509 $
 * 
 */
public class PirolPlugInMessages implements HandlerToMakeYourLifeEasier {
    private static final String BUNDLE_NAME = "de.fhOsnabrueck.jump.pirol.resources.PirolPlugIns";
    
    private static boolean inited = false;

    protected static PersonalLogger logger = new PersonalLogger(DebugUserIds.OLE);
    /**
     * We don't need instances of the class!
     */
    private PirolPlugInMessages(){}

    /**
     * Get a translated PIROL text from the i18N system.
     *@param key the key (name) for the the text 
     *@return the translated text
     */
    public static String getString(String key) {
        if (!PirolPlugInMessages.inited){
            I18NPlug.setPlugInRessource("de.fhOsnabrueck.jump.pirol", PirolPlugInMessages.BUNDLE_NAME);
            PirolPlugInMessages.inited = true;
        }
        
        try {
            return I18NPlug.get("de.fhOsnabrueck.jump.pirol", key);
        } catch (MissingResourceException e) {
            logger.printMinorError("i18n key not found for: \"" + key + "\"");
            return "!" + key + "!";
        }
    }

    public static boolean isInited() {
        return inited;
    }
    
}
